expr

package
v0.1.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 26, 2026 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var Root = &RootExpr{
	HealthChecks: []*HealthCheckExpr{},
}

Functions

This section is empty.

Types

type HealthCheckExpr

type HealthCheckExpr struct {
	Paths []string
}

func (*HealthCheckExpr) EvalName

func (o *HealthCheckExpr) EvalName() string

EvalName returns the generic expression name used in error messages.

type RootExpr

type RootExpr struct {
	HealthChecks []*HealthCheckExpr
}

func (*RootExpr) DependsOn

func (r *RootExpr) DependsOn() []eval.Root

DependsOn tells the eval engine to run the goa DSL first.

func (*RootExpr) EvalName

func (r *RootExpr) EvalName() string

EvalName returns the name used in error messages.

func (*RootExpr) Packages

func (r *RootExpr) Packages() []string

Packages returns the import path to the Go packages that make up the DSL. This is used to skip frames that point to files in these packages when computing the location of errors.

func (*RootExpr) WalkSets

func (r *RootExpr) WalkSets(walk eval.SetWalker)

WalkSets iterates over the API-level and service-level CORS definitions.

Jump to